PYMEX package is a collection of modules providing tools for accessing interaction
data distributed by The IMEx Consortium partners as well as for parsing, transformation
and construction of PSI-MI endorsed interaction data files.



